@@ -585,8 +585,14 @@ class ClassMemberStubsGenerator(FreeFunctionStubsGenerator):
             )
         for sig in self.signatures:
             args = sig.args
-            if not args.strip().startswith("self"):
-                result.append("@staticmethod")
+            sargs = args.strip()
+            if not sargs.startswith("self"):
+                if sargs.startswith("cls"):
+                    result.append("@classmethod")
+                    # remove type of cls
+                    args = ",".join(["cls"] + sig.split_arguments()[1:])
+                else:
+                    result.append("@staticmethod")
             else:
                 # remove type of self
                 args = ",".join(["self"] + sig.split_arguments()[1:])
@@ -682,6 +688,7 @@ class ClassStubsGenerator(StubsGenerator):
         self.fields = []  # type: List[AttributeStubsGenerator]
         self.properties = []  # type: List[PropertyStubsGenerator]
         self.methods = []  # type: List[ClassMemberStubsGenerator]
+        self.alias = []
 
         self.base_classes = []
         self.involved_modules_names = set()  # Set[str]
@@ -716,7 +723,9 @@ class ClassStubsGenerator(StubsGenerator):
                 continue
             if name.startswith("__pybind11_module"):
                 continue
-            if inspect.isroutine(member):
+            if (inspect.isroutine(member) or inspect.isclass(member)) and name != member.__name__:
+                self.alias.append(AliasStubsGenerator(name, member))
+            elif inspect.isroutine(member):
                 self.methods.append(
                     ClassMemberStubsGenerator(name, member, self.klass.__module__)
                 )
@@ -741,7 +750,8 @@ class ClassStubsGenerator(StubsGenerator):
 
         for x in itertools.chain(
             self.classes, self.methods, self.properties, self.fields
-        ):
+        ,
+                                 self.alias):
             x.parse()
 
         for B in bases:
@@ -795,6 +805,32 @@ class ClassStubsGenerator(StubsGenerator):
         return result
 
 
+class AliasStubsGenerator(StubsGenerator):
+
+    def __init__(self, alias_name, origin):
+        self.alias_name = alias_name
+        self.origin = origin
+
+    def parse(self):
+        pass
+
+    def to_lines(self): # type: () -> List[str]
+        return [
+            "{alias} = {origin}".format(
+                alias=self.alias_name,
+                origin=self.fully_qualified_name(self.origin)
+            )
+        ]
+
+    def get_involved_modules_names(self): # type: () -> Set[str]
+        if inspect.ismodule(self.origin):
+            return {self.origin.__name__}
+        elif inspect.isroutine(self.origin) or inspect.isclass(self.origin):
+            return {self.origin.__module__.__name__}
+        else:
+            return set()
+
+
 class ModuleStubsGenerator(StubsGenerator):
     CLASS_NAME_BLACKLIST = ClassStubsGenerator.CLASS_NAME_BLACKLIST
     ATTRIBUTES_BLACKLIST = (
@@ -827,6 +863,7 @@ class ModuleStubsGenerator(StubsGenerator):
         self.imported_modules = []  # type: List[str]
         self.imported_classes = {}  # type: Dict[str, type]
         self.attributes = []  # type: List[AttributeStubsGenerator]
+        self.alias = []
         self.stub_suffix = ""
         self.write_setup_py = False
 
@@ -839,7 +876,9 @@ class ModuleStubsGenerator(StubsGenerator):
         _visited_objects.append(self.module)
         logger.debug("Parsing '%s' module" % self.module.__name__)
         for name, member in inspect.getmembers(self.module):
-            if inspect.ismodule(member):
+            if (inspect.isfunction(member) or inspect.isclass(member)) and name != member.__name__:
+                self.alias.append(AliasStubsGenerator(name, member))
+            elif inspect.ismodule(member):
                 m = ModuleStubsGenerator(member)
                 if m.module.__name__.split(".")[:-1] == self.module.__name__.split("."):
                     self.submodules.append(m)
@@ -956,7 +995,8 @@ class ModuleStubsGenerator(StubsGenerator):
             + "\n]\n\n"
         )
 
-        for x in itertools.chain(self.classes, self.free_functions, self.attributes):
+        for x in itertools.chain(self.classes, self.free_functions, self.attributes,
+                                 self.alias):
             result.extend(x.to_lines())
         result.append("")  # Newline at EOF
         return result
